@@ -24,9 +24,15 @@ def query_exception_handler(exceptions: tuple = (SQLAlchemyError, )):
             try:
                 return function(*args, **kwargs)
             except exceptions as ex:
+                if ex.__dict__.get('orig') is not None:
+                    ex.__dict__['orig'] = 'Server Error: {ex}'.format(
+                        ex=str(ex.__dict__['orig'])
+                    )
+                    raise ex
+
                 raise Exception(
                     'Server Error: {ex}'.format(
-                        ex=str(ex.__dict__['orig'])
+                        ex=str(ex)
                     )
                 )
 
